package org.jeecg.modules.app.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.app.dto.GetPlaceListDTO;
import org.jeecg.modules.app.service.IAppHomeService;
import org.jeecg.modules.app.service.IUserService;
import org.jeecg.modules.app.vo.HomeVO;
import org.jeecg.modules.app.vo.MsgInfoVO;
import org.jeecg.modules.app.vo.MsgVO;
import org.jeecg.modules.app.vo.PlaceVO;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@Slf4j
@Tag(name = "App首页相关接口")
@RestController
@RequestMapping("/app/home")
public class AppHomeController {
    @Resource
    private IAppHomeService appHomeService;
    @Resource
    private IUserService userService;

    @GetMapping("/homeInfo")
    @Operation(summary = "查询首页轮播图")
    public Result<HomeVO> homeInfo() {
        return Result.ok(appHomeService.homeInfo());
    }
    /**
     * @Author SheepHy
     * @Description 查询消息通知列表（简略）
     * @Date 17:13 2025/7/3
     * @return List<MsgVO> {@link List<MsgVO>}
     **/
    @GetMapping("/getMsg")
    @Operation(summary = "查询消息通知列表（简略）")
    public Result<List<MsgVO>> getMsg(){
        return Result.ok(userService.getMsg());
    }

    /**
     * @Author SheepHy
     * @Description 查询消息详情
     * @Date 17:29 2025/7/3
     * @Param id 消息ID
     * @return MsgInfoVO {@link MsgInfoVO}
     **/
    @GetMapping("/getMsgInfo")
    @Operation(summary = "查询消息详情")
    public Result<MsgInfoVO> getMsgInfo(@RequestParam(required = false) @Schema(description = "消息ID") String id){
        return Result.ok(userService.getMsgInfo(id));
    }

    /**
     * @Author SheepHy
     * @Description 场地列表查询
     * @Date 10:37 2025/7/4
     * @Param
     * @return
     **/
    @PostMapping("/getPlaceList")
    @Operation(summary = "场地列表查询")
    public Result<Page<PlaceVO>> getPlaceList(@RequestBody GetPlaceListDTO getPlaceListDTO){
        return Result.ok(appHomeService.getPlaceList(getPlaceListDTO));
    }
}
