package org.jeecg.modules.system.app.controller;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.query.QueryRuleEnum;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.system.app.entity.AppSitePeiceRules;
import org.jeecg.modules.system.app.service.IAppSitePeiceRulesService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;
 /**
 * @Description: 场地价格规则表
 * @Author: jeecg-boot
 * @Date:   2025-07-03
 * @Version: V1.0
 */
@Tag(name="场地价格规则表")
@RestController
@RequestMapping("/org/jeecg/modules/app/appSitePeiceRules")
@Slf4j
public class AppSitePeiceRulesController extends JeecgController<AppSitePeiceRules, IAppSitePeiceRulesService> {
	@Autowired
	private IAppSitePeiceRulesService appSitePeiceRulesService;
	
	/**
	 * 分页列表查询
	 *
	 * @param appSitePeiceRules
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "场地价格规则表-分页列表查询")
	@Operation(summary="场地价格规则表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<AppSitePeiceRules>> queryPageList(AppSitePeiceRules appSitePeiceRules,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {


        QueryWrapper<AppSitePeiceRules> queryWrapper = QueryGenerator.initQueryWrapper(appSitePeiceRules, req.getParameterMap());
		Page<AppSitePeiceRules> page = new Page<AppSitePeiceRules>(pageNo, pageSize);
		IPage<AppSitePeiceRules> pageList = appSitePeiceRulesService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param appSitePeiceRules
	 * @return
	 */
	@AutoLog(value = "场地价格规则表-添加")
	@Operation(summary="场地价格规则表-添加")
	@RequiresPermissions("org.jeecg.modules.app:nm_site_peice_rules:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody AppSitePeiceRules appSitePeiceRules) {
		appSitePeiceRulesService.save(appSitePeiceRules);

		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param appSitePeiceRules
	 * @return
	 */
	@AutoLog(value = "场地价格规则表-编辑")
	@Operation(summary="场地价格规则表-编辑")
	@RequiresPermissions("org.jeecg.modules.app:nm_site_peice_rules:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody AppSitePeiceRules appSitePeiceRules) {
		appSitePeiceRulesService.updateById(appSitePeiceRules);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "场地价格规则表-通过id删除")
	@Operation(summary="场地价格规则表-通过id删除")
	@RequiresPermissions("org.jeecg.modules.app:nm_site_peice_rules:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		appSitePeiceRulesService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "场地价格规则表-批量删除")
	@Operation(summary="场地价格规则表-批量删除")
	@RequiresPermissions("org.jeecg.modules.app:nm_site_peice_rules:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.appSitePeiceRulesService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "场地价格规则表-通过id查询")
	@Operation(summary="场地价格规则表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<AppSitePeiceRules> queryById(@RequestParam(name="id",required=true) String id) {
		AppSitePeiceRules appSitePeiceRules = appSitePeiceRulesService.getById(id);
		if(appSitePeiceRules==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(appSitePeiceRules);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param appSitePeiceRules
    */
    @RequiresPermissions("org.jeecg.modules.app:nm_site_peice_rules:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, AppSitePeiceRules appSitePeiceRules) {
        return super.exportXls(request, appSitePeiceRules, AppSitePeiceRules.class, "场地价格规则表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("org.jeecg.modules.app:nm_site_peice_rules:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, AppSitePeiceRules.class);
    }

}
